結果
| 問題 | No.224 文字列変更(easy) |
| コンテスト | |
| ユーザー |
👑 |
| 提出日時 | 2020-06-09 21:11:55 |
| 言語 | Python3 (3.15.0 + numpy 2.5.4 + scipy 1.18.1 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 20 ms / 5,000 ms |
| + 681µs | |
| コード長 | 122 bytes |
| 記録 | |
| コンパイル時間 | 53 ms |
| コンパイル使用メモリ | 15,232 KB |
| 実行使用メモリ | 11,008 KB |
| 最終ジャッジ日時 | 2026-10-10 08:13:51 |
| 合計ジャッジ時間 | 1,935 ms |
|
ジャッジサーバーID (参考情報) |
judge4_0 / judge3_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| other | AC * 22 |
ソースコード
n = int(input())
s_s = input()
t_s = input()
ans = 0
for s, t in zip(s_s, t_s):
if s != t:
ans += 1
print(ans)